
The GDAPS frontend library allows GDAPS to add a frontend to plugins.

This library provides basic tools and classes for specific frontend modules,
like gdaps-frontend-vue. It doesn't do anything on its own.
